sfs.plot2d
==========

.. automodule:: sfs.plot2d

   
   
   .. rubric:: Functions

   .. autosummary::
   
      add_colorbar
      amplitude
      level
      loudspeakers
      particles
      reference
      secondary_sources
      vectors
      virtualsource
   
   

   
   
   

   
   
   